#
# spec file for package python-cstruct
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2020-2022, Martin Hauke <mardnh@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-cstruct
Version:        5.3
Release:        1.5
Summary:        C-style structs for Python
License:        MIT
Group:          Development/Languages/Python
URL:            https://github.com/andreax79/python-cstruct
Source:         https://github.com/andreax79/python-cstruct/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
BuildArch:      noarch
%python_subpackages

%description
Convert C struct definitions into Python classes with methods for
serializing/deserializing. The usage is very simple: create a class
subclassing cstruct.CStruct and add a C struct definition as a
string in the struct field. The C struct definition is parsed at
runtime and the struct format string is generated. The class offers
the method "unpack" for deserializing a string of bytes into a
Python object and the method "pack" for serializing the values into
a string.

%prep
%setup -q

%build
%python_build

%install
%python_install
%python_expand find %{buildroot}%{$python_sitelib} -name "*.py" -exec sed -i -e '/^#!\//, 1d' {} \;
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
%pytest

%files %{python_files}
%license LICENSE
%doc changelog.txt README.md
%{python_sitelib}/cstruct
%{python_sitelib}/cstruct-%{version}*-info

%changelog
* Mon Jan  8 2024 Dirk Müller <dmueller@suse.com>
- update to 5.3:
  * fix struct in struct array parsing
  * Python 3.12 support
* Tue Dec  6 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
- Update to version 5.2
  Fix
  - nested struct unpack fix
  - nested anonymous union offset fix
  - inspect offset for nested struct/union fix
- Update to version 5.1
  Improved
  * Support unpack from ctype pointers
  Added
  * Add support for char constants
  * Add native type test
  * dir.py example
* Sat Nov 12 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 5.0
  * Add support for enums
  * Add support for multiple definition to cstruct.parse
  * Add inspect method
* Fri Nov  4 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 4.0
  * Add enum support to cstruct.parse
  * Add typedef parsing
* Mon Oct 24 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.3
  * Fix tests on 32bit architecture
- Update to version 3.2
  * Add more tests
* Fri Oct 14 2022 Martin Hauke <mardnh@gmx.de>
- Update to version 3.1
  * Make CStruct/MemCStruct Pickle Friendly
- Update to version 3.0
  * Flexible array support
- Update to version 2.3
  * Fix compare with None
- Update to version 2.2
  Fixes
  * Fix empty MemCStruct size
  Improvements
  * Python 3.10 support
  * pytest
  * black code style
* Thu Oct 13 2022 Dirk Müller <dmueller@suse.com>
- use https for urls
* Thu Aug 13 2020 Martin Hauke <mardnh@gmx.de>
- Initial package, version 1.8
